@@ -1,3 +1,5 @@
+from warnings import warn
+
 from ._core import make_figure
 from ._doc import make_docstring
 import plotly.graph_objs as go
@@ -55,6 +57,7 @@ def scatter(
     range_y=None,
     render_mode="auto",
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -105,6 +108,7 @@ def density_contour(
     nbinsy=None,
     text_auto=False,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -175,6 +179,7 @@ def density_heatmap(
     nbinsy=None,
     text_auto=False,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -253,12 +258,13 @@ def line(
     line_shape=None,
     render_mode="auto",
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
 ) -> go.Figure:
     """
-    In a 2D line plot, each row of `data_frame` is represented as vertex of
+    In a 2D line plot, each row of `data_frame` is represented as a vertex of
     a polyline mark in 2D space.
     """
     return make_figure(args=locals(), constructor=go.Scatter)
@@ -303,14 +309,15 @@ def area(
     range_y=None,
     line_shape=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
 ) -> go.Figure:
     """
     In a stacked area plot, each row of `data_frame` is represented as
-    vertex of a polyline mark in 2D space. The area between successive
-    polylines is filled.
+    a vertex of a polyline mark in 2D space. The area between
+    successive polylines is filled.
     """
     return make_figure(
         args=locals(),
@@ -362,6 +369,7 @@ def bar(
     range_y=None,
     text_auto=False,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -412,6 +420,7 @@ def timeline(
     range_x=None,
     range_y=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -467,6 +476,7 @@ def histogram(
     nbins=None,
     text_auto=False,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -541,6 +551,7 @@ def ecdf(
     range_x=None,
     range_y=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -597,6 +608,7 @@ def violin(
     points=None,
     box=False,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -650,6 +662,7 @@ def box(
     points=None,
     notched=False,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -700,6 +713,7 @@ def strip(
     range_x=None,
     range_y=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -765,6 +779,7 @@ def scatter_3d(
     range_y=None,
     range_z=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -816,12 +831,13 @@ def line_3d(
     range_y=None,
     range_z=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
 ) -> go.Figure:
     """
-    In a 3D line plot, each row of `data_frame` is represented as vertex of
+    In a 3D line plot, each row of `data_frame` is represented as a vertex of
     a polyline mark in 3D space.
     """
     return make_figure(args=locals(), constructor=go.Scatter3d)
@@ -856,6 +872,7 @@ def scatter_ternary(
     opacity=None,
     size_max=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -896,13 +913,14 @@ def line_ternary(
     markers=False,
     line_shape=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
 ) -> go.Figure:
     """
     In a ternary line plot, each row of `data_frame` is represented as
-    vertex of a polyline mark in ternary coordinates.
+    a vertex of a polyline mark in ternary coordinates.
     """
     return make_figure(args=locals(), constructor=go.Scatterternary)
 
@@ -941,6 +959,7 @@ def scatter_polar(
     log_r=False,
     render_mode="auto",
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -987,13 +1006,14 @@ def line_polar(
     range_theta=None,
     log_r=False,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
 ) -> go.Figure:
     """
-    In a polar line plot, each row of `data_frame` is represented as vertex
-    of a polyline mark in polar coordinates.
+    In a polar line plot, each row of `data_frame` is represented as a
+    vertex of a polyline mark in polar coordinates.
     """
     return make_figure(args=locals(), constructor=go.Scatterpolar)
 
@@ -1030,6 +1050,7 @@ def bar_polar(
     range_theta=None,
     log_r=False,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -1080,6 +1101,7 @@ def choropleth(
     fitbounds=None,
     basemap_visible=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -1088,6 +1110,16 @@ def choropleth(
     In a choropleth map, each row of `data_frame` is represented by a
     colored region mark on a map.
     """
+
+    if locationmode == "country names":
+        warn(
+            "The library used by the *country names* `locationmode` option is changing in an upcoming version. "
+            "Country names in existing plots may not work in the new version. "
+            "To ensure consistent behavior, consider setting `locationmode` to *ISO-3*.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+
     return make_figure(
         args=locals(),
         constructor=go.Choropleth,
@@ -1137,6 +1169,7 @@ def scatter_geo(
     fitbounds=None,
     basemap_visible=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -1145,6 +1178,16 @@ def scatter_geo(
     In a geographic scatter plot, each row of `data_frame` is represented
     by a symbol mark on a map.
     """
+
+    if locationmode == "country names":
+        warn(
+            "The library used by the *country names* `locationmode` option is changing in an upcoming version. "
+            "Country names in existing plots may not work in the new version. "
+            "To ensure consistent behavior, consider setting `locationmode` to *ISO-3*.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+
     return make_figure(
         args=locals(),
         constructor=go.Scattergeo,
@@ -1193,13 +1236,14 @@ def line_geo(
     fitbounds=None,
     basemap_visible=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
 ) -> go.Figure:
     """
     In a geographic line plot, each row of `data_frame` is represented as
-    vertex of a polyline mark on a map.
+    a vertex of a polyline mark on a map.
     """
     return make_figure(
         args=locals(),
@@ -1211,6 +1255,157 @@ def line_geo(
 line_geo.__doc__ = make_docstring(line_geo)
 
 
+def scatter_map(
+    data_frame=None,
+    lat=None,
+    lon=None,
+    color=None,
+    text=None,
+    hover_name=None,
+    hover_data=None,
+    custom_data=None,
+    size=None,
+    animation_frame=None,
+    animation_group=None,
+    category_orders=None,
+    labels=None,
+    color_discrete_sequence=None,
+    color_discrete_map=None,
+    color_continuous_scale=None,
+    range_color=None,
+    color_continuous_midpoint=None,
+    opacity=None,
+    size_max=None,
+    zoom=8,
+    center=None,
+    map_style=None,
+    title=None,
+    subtitle=None,
+    template=None,
+    width=None,
+    height=None,
+) -> go.Figure:
+    """
+    In a scatter map, each row of `data_frame` is represented by a
+    symbol mark on the map.
+    """
+    return make_figure(args=locals(), constructor=go.Scattermap)
+
+
+scatter_map.__doc__ = make_docstring(scatter_map)
+
+
+def choropleth_map(
+    data_frame=None,
+    geojson=None,
+    featureidkey=None,
+    locations=None,
+    color=None,
+    hover_name=None,
+    hover_data=None,
+    custom_data=None,
+    animation_frame=None,
+    animation_group=None,
+    category_orders=None,
+    labels=None,
+    color_discrete_sequence=None,
+    color_discrete_map=None,
+    color_continuous_scale=None,
+    range_color=None,
+    color_continuous_midpoint=None,
+    opacity=None,
+    zoom=8,
+    center=None,
+    map_style=None,
+    title=None,
+    subtitle=None,
+    template=None,
+    width=None,
+    height=None,
+) -> go.Figure:
+    """
+    In a choropleth map, each row of `data_frame` is represented by a
+    colored region on the map.
+    """
+    return make_figure(args=locals(), constructor=go.Choroplethmap)
+
+
+choropleth_map.__doc__ = make_docstring(choropleth_map)
+
+
+def density_map(
+    data_frame=None,
+    lat=None,
+    lon=None,
+    z=None,
+    hover_name=None,
+    hover_data=None,
+    custom_data=None,
+    animation_frame=None,
+    animation_group=None,
+    category_orders=None,
+    labels=None,
+    color_continuous_scale=None,
+    range_color=None,
+    color_continuous_midpoint=None,
+    opacity=None,
+    zoom=8,
+    center=None,
+    map_style=None,
+    radius=None,
+    title=None,
+    subtitle=None,
+    template=None,
+    width=None,
+    height=None,
+) -> go.Figure:
+    """
+    In a density map, each row of `data_frame` contributes to the intensity of
+    the color of the region around the corresponding point on the map.
+    """
+    return make_figure(
+        args=locals(), constructor=go.Densitymap, trace_patch=dict(radius=radius)
+    )
+
+
+density_map.__doc__ = make_docstring(density_map)
+
+
+def line_map(
+    data_frame=None,
+    lat=None,
+    lon=None,
+    color=None,
+    text=None,
+    hover_name=None,
+    hover_data=None,
+    custom_data=None,
+    line_group=None,
+    animation_frame=None,
+    animation_group=None,
+    category_orders=None,
+    labels=None,
+    color_discrete_sequence=None,
+    color_discrete_map=None,
+    zoom=8,
+    center=None,
+    map_style=None,
+    title=None,
+    subtitle=None,
+    template=None,
+    width=None,
+    height=None,
+) -> go.Figure:
+    """
+    In a line map, each row of `data_frame` is represented as
+    a vertex of a polyline mark on the map.
+    """
+    return make_figure(args=locals(), constructor=go.Scattermap)
+
+
+line_map.__doc__ = make_docstring(line_map)
+
+
 def scatter_mapbox(
     data_frame=None,
     lat=None,
@@ -1236,14 +1431,24 @@ def scatter_mapbox(
     center=None,
     mapbox_style=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
 ) -> go.Figure:
     """
+    *scatter_mapbox* is deprecated! Use *scatter_map* instead.
+    Learn more at: https://plotly.com/python/mapbox-to-maplibre/
     In a Mapbox scatter plot, each row of `data_frame` is represented by a
     symbol mark on a Mapbox map.
     """
+    warn(
+        "*scatter_mapbox* is deprecated!"
+        + " Use *scatter_map* instead."
+        + " Learn more at: https://plotly.com/python/mapbox-to-maplibre/",
+        stacklevel=2,
+        category=DeprecationWarning,
+    )
     return make_figure(args=locals(), constructor=go.Scattermapbox)
 
 
@@ -1273,14 +1478,24 @@ def choropleth_mapbox(
     center=None,
     mapbox_style=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
 ) -> go.Figure:
     """
+    *choropleth_mapbox* is deprecated! Use *choropleth_map* instead.
+    Learn more at: https://plotly.com/python/mapbox-to-maplibre/
     In a Mapbox choropleth map, each row of `data_frame` is represented by a
     colored region on a Mapbox map.
     """
+    warn(
+        "*choropleth_mapbox* is deprecated!"
+        + " Use *choropleth_map* instead."
+        + " Learn more at: https://plotly.com/python/mapbox-to-maplibre/",
+        stacklevel=2,
+        category=DeprecationWarning,
+    )
     return make_figure(args=locals(), constructor=go.Choroplethmapbox)
 
 
@@ -1308,14 +1523,24 @@ def density_mapbox(
     mapbox_style=None,
     radius=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
 ) -> go.Figure:
     """
+    *density_mapbox* is deprecated! Use *density_map* instead.
+    Learn more at: https://plotly.com/python/mapbox-to-maplibre/
     In a Mapbox density map, each row of `data_frame` contributes to the intensity of
     the color of the region around the corresponding point on the map
     """
+    warn(
+        "*density_mapbox* is deprecated!"
+        + " Use *density_map* instead."
+        + " Learn more at: https://plotly.com/python/mapbox-to-maplibre/",
+        stacklevel=2,
+        category=DeprecationWarning,
+    )
     return make_figure(
         args=locals(), constructor=go.Densitymapbox, trace_patch=dict(radius=radius)
     )
@@ -1344,14 +1569,24 @@ def line_mapbox(
     center=None,
     mapbox_style=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
 ) -> go.Figure:
     """
+    *line_mapbox* is deprecated! Use *line_map* instead.
+    Learn more at: https://plotly.com/python/mapbox-to-maplibre/
     In a Mapbox line plot, each row of `data_frame` is represented as
-    vertex of a polyline mark on a Mapbox map.
+    a vertex of a polyline mark on a Mapbox map.
     """
+    warn(
+        "*line_mapbox* is deprecated!"
+        + " Use *line_map* instead."
+        + " Learn more at: https://plotly.com/python/mapbox-to-maplibre/",
+        stacklevel=2,
+        category=DeprecationWarning,
+    )
     return make_figure(args=locals(), constructor=go.Scattermapbox)
 
 
@@ -1379,6 +1614,7 @@ def scatter_matrix(
     opacity=None,
     size_max=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -1406,6 +1642,7 @@ def parallel_coordinates(
     range_color=None,
     color_continuous_midpoint=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -1430,6 +1667,7 @@ def parallel_categories(
     range_color=None,
     color_continuous_midpoint=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -1465,6 +1703,7 @@ def pie(
     category_orders=None,
     labels=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -1517,6 +1756,7 @@ def sunburst(
     custom_data=None,
     labels=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -1567,6 +1807,7 @@ def treemap(
     custom_data=None,
     labels=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -1617,6 +1858,7 @@ def icicle(
     custom_data=None,
     labels=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -1676,6 +1918,7 @@ def funnel(
     range_x=None,
     range_y=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
@@ -1702,6 +1945,7 @@ def funnel_area(
     custom_data=None,
     labels=None,
     title=None,
+    subtitle=None,
     template=None,
     width=None,
     height=None,
